jpc - Leidenschaft für Musik
Description: jpc Online-Shop - wählen Sie aus mehr als 4 Millionen CDs, DVDs, Blu-rays und Büchern. Portofrei ab 20 Euro und bei Bestellungen mit Buch.

Anmelden Konto anlegen

## Ihr Warenkorb

Schritt 1 von 5
Es befinden sich 0 Artikel im Wert von 0,00 Euro* im Warenkorb. Gutschein einlösen | Bestellschein
Vermissen Sie Artikel in Ihrem Warenkorb? Bitte aktivieren Sie Cookies.

### Versandkosten

Lieferungen ab einem Bestellwert von 0 Euro werden Ihnen innerhalb Deutschlands porto- und versandkostenfrei geliefert, bei einem geringeren Bestellwert wird ein Versandanteil von 2,99 Euro berechnet. Bestellungen, die mindestens ein Buch enthalten, werden Ihnen innerhalb Deutschlands immer porto- und versandkostenfrei geliefert.

Informationen zu Versandkosten für Lieferungen außerhalb Deutschlands finden Sie in unseren Allgemeinen Geschäftsbedingungen.

### Hinweise zur Bestellung

Den Bestellvorgang zu unseren Allgemeinen Geschäftsbedingungen leiten Sie ein, indem Sie auf den Button "Bestellen" klicken. Prüfen Sie jedoch zuvor auf dieser Seite, ob die Anzahl der Artikel in Ihrem Warenkorb korrekt ist. Hier können Sie die Menge aktualisieren oder Artikel löschen. Nach Eingabe der gewünschten Zahlungsart auf der folgenden Seite werden Ihre Angaben auf einer weiteren Seite noch einmal zur Korrektur von eventuellen Eingabefehlern aufgeführt. Bestätigen Sie dort durch Klick auf "Bestellung abschicken" Ihre Bestellung. Dieser Online-Shop steht derzeit in deutscher und englischer Sprache zur Verfügung. Der Kaufvertrag kommt zustande, wenn wir Ihre Bestellung durch Lieferung der Ware bzw. durch die Mitteilung der Auslieferung annehmen.

### Bestelleingangsbestätigung, Speichermöglichkeiten

Sie erhalten zusätzlich eine Bestätigung per E-Mail über den Eingang der Bestellung. Sie enthält noch einmal alle Daten und unsere Allgemeinen Geschäftsbedingungen. Ihre konkreten Bestelldaten werden bei uns außerdem gespeichert. Sie können diese Daten auf unserer Internetpräsenz unter "Mein Konto" abrufen und über Ihr Internetdienstprogramm (Browser) speichern. Weiter können Sie dort auch über ein Kontaktformular mit uns in Verbindung treten, um z.B. Ihre Adresse oder Ihre Zahlungsart bei offenen Bestellungen zu ändern. Dies geschieht zu Ihrer Sicherheit, wie alles andere im Login-Bereich auch, über eine verschlüsselte Verbindung (SSL).

### Ihr Vertragspartner

jpc-schallplatten Versandhandelsgesellschaft mbH Lübecker Straße 9 D-49124 Georgsmarienhütte

Geschäftsführer: Gerhard Georg Ortmann AG Osnabrück HRB 110327

Um die Übertragung Ihrer Adress- und Zahlungsdaten abzusichern, erfolgt die Kommunikation mit jpc über eine verschlüsselte Verbindung (SSL).

Informationen zur Lieferbarkeit bzw. zu Veröffentlichungsterminen von Artikeln beruhen auf Vorabinformationen unserer Lieferanten. Diese Termine sind ohne Gewähr und können sich jederzeit ändern.
© jpc-schallplatten Versandhandelsgesellschaft mbH